# Check if collection exits in database and initialize database only if not
if python3 manage.py id check "${COLLECTION}"; then
    echo "Initialize database"

    python3 manage.py coveragetype import /rgbnir_definition.json --traceback

    if [ "${COLLECTION}" == "VHR_IMAGE_2018" ]; then
        echo "Initializing collection '${COLLECTION}'."

        # PL00
        python3 manage.py producttype create "${COLLECTION}"_Product_PL00 --traceback \
            --coverage-type "RGBNir"
        python3 manage.py browsetype create "${COLLECTION}"_Product_PL00 --traceback \
            --red "red" \
            --green "green" \
            --blue "blue" \
            --red-range 1000 15000 \
            --green-range 1000 15000 \
            --blue-range 1000 15000 \
            --red-nodata 0 \
            --green-nodata 0 \
            --blue-nodata 0
        python3 manage.py browsetype create "${COLLECTION}"_Product_PL00 "TRUE_COLOR" --traceback \
            --red "red" \
            --green "green" \
            --blue "blue" \
            --red-range 1000 15000 \
            --green-range 1000 15000 \
            --blue-range 1000 15000 \
            --red-nodata 0 \
            --green-nodata 0 \
            --blue-nodata 0
        python3 manage.py browsetype create "${COLLECTION}"_Product_PL00 "FALSE_COLOR" --traceback \
            --red "nir" \
            --green "red" \
            --blue "green" \
            --red-range 1000 15000 \
            --green-range 1000 15000 \
            --blue-range 1000 15000 \
            --red-nodata 0 \
            --green-nodata 0 \
            --blue-nodata 0
        python3 manage.py browsetype create "${COLLECTION}"_Product_PL00 "NDVI" --traceback \
            --grey "(nir-red)/(nir+red)" --grey-range -1 1


        python3 manage.py collectiontype create "${COLLECTION}"_Collection --traceback \
            --coverage-type "RGBNir" \
            --product-type "${COLLECTION}"_Product_PL00

        # Create collections for all products
        python3 manage.py collection create "${COLLECTION}" --type "${COLLECTION}"_Collection --traceback

        # Register mask type
        python3 manage.py masktype create --validity "${COLLECTION}"_Product_PL00 validity

    else
        echo "Provided collection '${COLLECTION}' not valid."
    fi

    python3 manage.py storageauth create auth-cloud-ovh "${OS_AUTH_URL_SHORT}" \
        --type keystone \
        -p auth-version "${ST_AUTH_VERSION}" \
        -p identity-api-version="${ST_AUTH_VERSION}" \
        -p username "${OS_USERNAME}" \
        -p password "${OS_PASSWORD}" \
        -p tenant-name "${OS_TENANT_NAME}" \
        -p tenant-id "${OS_TENANT_ID}" \
        -p region-name "${OS_REGION_NAME}"

    python3 manage.py storage create \
        ${UPLOAD_CONTAINER} ${UPLOAD_CONTAINER} \
        --type swift \
        --storage-auth auth-cloud-ovh


else
    echo "Using existing database"
fi
